package com.github.niefy.modules.wx.manage;

import com.alibaba.fastjson.JSONObject;
import com.github.niefy.common.utils.PageUtils;
import com.github.niefy.common.utils.R;
import com.github.niefy.common.utils.StringUtils;
import com.github.niefy.config.TaskExcutor;
import com.github.niefy.modules.wx.entity.TemplateMsgLog;
import com.github.niefy.modules.wx.entity.WxUser;
import com.github.niefy.modules.wx.service.TemplateMsgLogService;
import com.github.niefy.modules.wx.service.TemplateMsgService;
import com.github.niefy.modules.wx.service.WxUserService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import me.chanjar.weixin.mp.api.WxMpService;
import me.chanjar.weixin.mp.bean.template.WxMpTemplateData;
import me.chanjar.weixin.mp.bean.template.WxMpTemplateMessage;
import me.chanjar.weixin.mp.enums.WxMpApiUrl;
import me.chanjar.weixin.mp.util.WxMpConfigStorageHolder;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;


/**
 * 模版消息发送记录
 *
 * @author niefy
 * @email niefy@qq.com
 * @date 2019-11-12 18:30:15
 */
@RestController
@RequestMapping("/manage/templateMsg")
@Api(tags = {"模板消息发送-管理后台"})
public class TemplateMsgManageController {
    @Autowired
    TemplateMsgService templateMsgService;
    @Autowired
    private WxUserService userService;

    /**
     * 发送模板消息给用户
     * 添加消息模板指引：https://kf.qq.com/faq/170209E3InyI170209nIF7RJ.html
     * 示例消息模板为：{{first.DATA}} ↵商品名称：{{keyword1.DATA}} ↵购买时间：{{keyword2.DATA}} ↵{{remark.DATA}}
     * 参数：json字符串，需进行解析
     * eg:{"phones":"18811408841,18811408841","datas":"dept-威海市乳山市|dept-威海市乳山市","appid":"公众号appid","templateId":"模板IDtemplateId","url":"url"}
     * 使用固定线程的线程池
     */
    @GetMapping("/sendTemplateMsg/{templateMsg}")
    @ApiOperation(value = "外部接口-发送模板信息")
    public void sendTemplateMsg(@PathVariable("templateMsg") String templateMsg) {
        TaskExcutor.submit(() -> {
            JSONObject templateMsgObject = JSONObject.parseObject(templateMsg);
            String phones = templateMsgObject.getString("phones");//所有手机号
            String phoness[] = phones.split(",");
            for (String phone:phoness) {
                WxUser wxUser = userService.findByPhone(phone);
                if(StringUtils.isNotNull(wxUser)){
                    String datas = templateMsgObject.getString("datas");//所有模板内容
                    String appid = templateMsgObject.getString("appid");
                    String templateId = templateMsgObject.getString("templateId");
                    String url = templateMsgObject.getString("url");
                    String datass[] = datas.split("\\|");
                    List<WxMpTemplateData> data = new ArrayList<>();
                    for (String data_z:datass) {
                        String data_zz[] = data_z.split("-");
                        data.add(new WxMpTemplateData(data_zz[0], data_zz[1]));
                    }
                    WxMpTemplateMessage wxMpTemplateMessage = WxMpTemplateMessage.builder()
                            .templateId(templateId)
                            .url(url)
                            .toUser(wxUser.getOpenid())
                            .data(data)
                            .build();
                    templateMsgService.sendTemplateMsg(wxMpTemplateMessage,appid);
                }
            }
        });
    }
}
